@@ -1,7 +1,9 @@
 //! A Koto language module for working with JSON data
 
 use {
-    koto_runtime::{runtime_error, Value, ValueList, ValueMap, ValueVec},
+    koto_runtime::{
+        runtime_error, unexpected_type_error_with_slice, Value, ValueList, ValueMap, ValueVec,
+    },
     koto_serialize::SerializableValue,
     serde_json::Value as JsonValue,
 };
@@ -56,7 +58,9 @@ pub fn make_module() -> ValueMap {
                 e.to_string()
             ),
         },
-        _ => runtime_error!("json.from_string expects a string as argument"),
+        unexpected => {
+            unexpected_type_error_with_slice("json.from_string", "a String as argument", unexpected)
+        }
     });
 
     result.add_fn("to_string", |vm, args| match vm.get_args(args) {
@@ -64,7 +68,9 @@ pub fn make_module() -> ValueMap {
             Ok(result) => Ok(Str(result.into())),
             Err(e) => runtime_error!("json.to_string: {}", e),
         },
-        _ => runtime_error!("json.to_string expects a single argument"),
+        unexpected => {
+            unexpected_type_error_with_slice("json.to_string", "a Value as argument", unexpected)
+        }
     });
 
     result
